@@ -1,7 +1,7 @@
 """Contains fuel level structure decoder."""
 from __future__ import annotations
 
-from typing import Final, Optional, Tuple
+from typing import Final
 
 from pyplumio.const import BYTE_UNDEFINED
 from pyplumio.helpers.typing import DeviceDataType
@@ -14,8 +14,8 @@ class FuelLevelStructure(StructureDecoder):
     """Represents fuel level sensor data structure."""
 
     def decode(
-        self, message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
-    ) -> Tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
+    ) -> tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         if message[offset] == BYTE_UNDEFINED:
             return ensure_device_data(data), offset + 1
