@@ -1,7 +1,7 @@
 """Contains output flags structure decoder."""
 from __future__ import annotations
 
-from typing import Final, Optional, Tuple
+from typing import Final
 
 from pyplumio import util
 from pyplumio.helpers.typing import DeviceDataType
@@ -17,8 +17,8 @@ class OutputFlagsStructure(StructureDecoder):
     """Represents output flags structure."""
 
     def decode(
-        self, message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
-    ) -> Tuple[DeviceDataType, int]:
+        self, message: bytearray, offset: int = 0, data: DeviceDataType | None = None
+    ) -> tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         output_flags = util.unpack_ushort(message[offset : offset + 4])
         return (
